<?php

namespace Bixo\Feed\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Feed\Actions\FeedAction;
use Bixo\Feed\Http\Requests\FeedActionRequest;
use Bixo\Feed\Http\Resources\FeedResource;
use Bixo\Feed\Models\Feed;

/**
 * Admin web controller class.
 */
class FeedActionController extends BaseController
{

    /**
     * Action controller function for feed.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(FeedActionRequest $request, Feed $feed, $action)
    {
        try {
            $request = $request->all();
            $feed = FeedAction::run($action, $feed, $request);

            $data = new FeedResource($feed);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('feed::feed.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('feed/feed/' . $feed->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('feed/feed/' . $feed->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
