<?php

namespace Bixo\Feed\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Bixo\Feed\Http\Resources\FeedResource;
use Bixo\Feed\Http\Resources\FeedsCollection;
use Bixo\Feed\Scopes\FeedPublicScope;
use Bixo\Feed\Models\Feed;

class FeedPublicController extends BaseController
{

    /**
     * Show feed's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Feed::pushScope(new RequestScope())
            ->pushScope(new FeedPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $feeds = new FeedsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('feed::feed.names'))
            ->view('feed::public.feed.index')
            ->data(compact('feeds', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show feed.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Feed::findBySlug($slug);
        $data = new FeedResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('feed::feed.name'))
            ->view('feed::public.feed.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
