<?php

namespace Bixo\Feed\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Feed\Actions\InteractionAction;
use Bixo\Feed\Http\Requests\InteractionActionRequest;
use Bixo\Feed\Http\Resources\InteractionResource;
use Bixo\Feed\Models\Interaction;

/**
 * Admin web controller class.
 */
class InteractionActionController extends BaseController
{

    /**
     * Action controller function for interaction.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(InteractionActionRequest $request, Interaction $interaction, $action)
    {
        try {
            $request = $request->all();
            $interaction = InteractionAction::run($action, $interaction, $request);

            $data = new InteractionResource($interaction);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('feed::interaction.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('feed/interaction/' . $interaction->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('feed/interaction/' . $interaction->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
