<?php

namespace Bixo\Feed\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Bixo\Feed\Http\Requests\InteractionActionsRequest;
use Bixo\Feed\Actions\InteractionActions;

/**
 * Admin web controller class.
 */
class InteractionActionsController extends BaseController
{

    /**
     * Action controller function for interaction.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(InteractionActionsRequest $request, $action)
    {
        try {
            $interaction = InteractionActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('feed::interaction.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('feed/interaction/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('feed/interaction/' . $action))
                ->redirect();
        }
    }
}
