<?php

namespace Bixo\Feed\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Bixo\Feed\Http\Resources\FeedResource;
use Bixo\Feed\Http\Resources\FeedsCollection;
use Bixo\Feed\Scopes\InteractionPublicScope;
use Bixo\Feed\Models\Interaction;

class InteractionPublicController extends BaseController
{

    /**
     * Show interaction's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Interaction::pushScope(new RequestScope())
            ->pushScope(new InteractionPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $interactions = new InteractionsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('feed::interaction.names'))
            ->view('feed::public.interaction.index')
            ->data(compact('interactions', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show interaction.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Interaction::findBySlug($slug);
        $data = new InteractionResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('feed::interaction.name'))
            ->view('feed::public.interaction.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
