<?php

namespace Bixo\Feed\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Feed\Events\InteractionWorkflow as InteractionWorkflowEvent;
use Bixo\Feed\Notifications\InteractionWorkflow as InteractionWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class InteractionWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(InteractionWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $interaction is submitted.
     *
     * @param InteractionWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(InteractionWorkflowEvent $event)
    {
        $client = $event->interaction->client;
        Notification::send($client, new InteractionWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $interaction is published.
     *
     * @param InteractionWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(InteractionWorkflowEvent $event)
    {
        $client = $event->interaction->client;
        Notification::send($client, new InteractionWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $interaction is approved.
     *
     * @param InteractionWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(InteractionWorkflowEvent $event)
    {
        $client = $event->interaction->client;
        Notification::send($client, new InteractionWorkflowNotification($event));
    }

    /**
     * Handles the $interaction workflow event as a listener.
     *
     * @param InteractionWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(InteractionWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
