<?php
namespace Bixo\Feed\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Feed\Events\InteractionAction as InteractionActionEvent;
use Bixo\Feed\Models\Interaction;

class InteractionAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $interaction;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param InteractionActionEvent $interaction
     */
    public function __construct(InteractionActionEvent $interaction)
    {
        $this->action = $event->action;
        $this->interaction = $interaction;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Interaction Approved - ' . config('app.name'))
            ->view('feed::interaction.email.action', ['data' => $this->interaction]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
