<?php

namespace Bixo\Feed\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Feed\Models\Feed;

class FeedPolicy
{

    use FeedAction;
    use FeedReport;
    use FeedWorkflow;

    /**
     * Determine if the given user can view the feed.
     *
     * @param Authenticatable $user
     * @param Feed $feed
     *
     * @return bool
     */
    public function view(Authenticatable $user, Feed $feed)
    {
        if ($authUser->canDo('feed.feed.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $feed->is_owner;
    }

    /**
     * Determine if the given user can create a feed.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('feed.feed.create');
    }

    /**
     * Determine if the given user can update the given feed.
     *
     * @param Authenticatable $user
     * @param Feed $feed
     *
     * @return bool
     */
    public function update(Authenticatable $user, Feed $feed)
    {
        if ($user->canDo('feed.feed.edit') && $user->isAdmin()) {
            return true;
        }

        return $feed->is_owner;
    }

    /**
     * Determine if the given user can delete the given feed.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Feed $feed)
    {
        return $feed->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
