<?php

namespace Bixo\Feed\Policies;

use Bixo\Feed\Models\Interaction;
use Illuminate\Foundation\Auth\User as Authenticatable;

trait InteractionWorkflow
{

    /**
     * Determine if the given user can approve the given interaction.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function approve(Authenticatable $user, Interaction $interaction)
    {
        if ($user->canDo('feed.interaction.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given interaction.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function submit(Authenticatable $user, Interaction $interaction)
    {
        if ($user->canDo('feed.interaction.submit')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given interaction.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function publish(Authenticatable $user, Interaction $interaction)
    {
        if ($user->canDo('feed.interaction.publish')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given interaction.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function unpublish(Authenticatable $user, Interaction $interaction)
    {
        if ($user->canDo('feed.interaction.unpublish')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given interaction.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function archive(Authenticatable $user, Interaction $interaction)
    {
        if ($user->canDo('feed.interaction.archive')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given interaction.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function unarchive(Authenticatable $user, Interaction $interaction)
    {
        if ($user->canDo('feed.interaction.unarchive')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given interaction.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function reject(Authenticatable $user, Interaction $interaction)
    {
        if ($user->canDo('feed.interaction.reject')) {
            return true;
        }

        return false;
    }

}
